==> mule-metadata-model-api-1.2.0-20210120-sources.jar: org/mule/metadata/api/model/impl/DefaultAttributeFieldType.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.api.model.impl;

import org.mule.metadata.api.annotation.TypeAnnotation;
import org.mule.metadata.api.model.AttributeFieldType;
import org.mule.metadata.api.model.AttributeKeyType;
import org.mule.metadata.api.model.MetadataFormat;
import org.mule.metadata.api.model.MetadataType;
import org.mule.metadata.api.visitor.MetadataTypeVisitor;

import java.util.Map;

public class DefaultAttributeFieldType extends BaseMetadataType implements AttributeFieldType {

  private AttributeKeyType key;
  private MetadataType value;
  private boolean required;

  public DefaultAttributeFieldType(AttributeKeyType key, MetadataType value, boolean required, MetadataFormat metadataFormat,
                                   Map<Class<? extends TypeAnnotation>, TypeAnnotation> extensions) {
    super(metadataFormat, extensions);
    this.key = key;
    this.value = value;
    this.required = required;
  }

  @Override
  public AttributeKeyType getKey() {
    return key;
  }

  @Override
  public MetadataType getValue() {
    return value;
  }

  @Override
  public boolean isRequired() {
    return required;
  }

  @Override
  public void accept(MetadataTypeVisitor visitor) {
    visitor.visitAttributeField(this);
  }
}

==> mule-metadata-model-api-1.3.0-20220919-sources.jar: org/mule/metadata/api/model/impl/DefaultAttributeFieldType.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.api.model.impl;

import org.mule.metadata.api.annotation.TypeAnnotation;
import org.mule.metadata.api.model.AttributeFieldType;
import org.mule.metadata.api.model.AttributeKeyType;
import org.mule.metadata.api.model.MetadataFormat;
import org.mule.metadata.api.model.MetadataType;
import org.mule.metadata.api.visitor.MetadataTypeVisitor;

import java.util.Map;

public class DefaultAttributeFieldType extends BaseMetadataType implements AttributeFieldType {

  private final AttributeKeyType key;
  private final MetadataType value;
  private final boolean required;

  public DefaultAttributeFieldType(AttributeKeyType key, MetadataType value, boolean required, MetadataFormat metadataFormat,
                                   Map<Class<? extends TypeAnnotation>, TypeAnnotation> extensions) {
    super(metadataFormat, extensions);
    this.key = key;
    this.value = value;
    this.required = required;
  }

  @Override
  public AttributeKeyType getKey() {
    return key;
  }

  @Override
  public MetadataType getValue() {
    return value;
  }

  @Override
  public boolean isRequired() {
    return required;
  }

  @Override
  public void accept(MetadataTypeVisitor visitor) {
    visitor.visitAttributeField(this);
  }
}
